@@ -40,6 +40,8 @@ char	SendBack;
 char	Connected;
 char	DVwait;
 unsigned char	PacketIdSave[2];
+unsigned int	crc;
+unsigned int	Packet_ID;
 
 struct  repMsg  reqConMsg;
 
@@ -96,23 +98,33 @@ void	voice_frame_send(void)
                         memcpy ((char *)&RelayPacket.dv, (char *)&send_pkt, 56);
                         RelayPacket.ip = dstIP;
                         RelayPacket.port = dstPort;
+        		RelayPacket.dv.B_header.PacketID[0] = (Packet_ID >> 8) & 0xff;
+        		RelayPacket.dv.B_header.PacketID[1] = Packet_ID & 0xff;
                         sndAddr.sin_family = PF_INET;
                         sndAddr.sin_port = db_port;
                         sndAddr.sin_addr = dbIP;
 			memcpy (&RelayPacket.dv.header.MyCall, &client_call, 8);
 			memcpy (&RelayPacket.dv.header.YourCall, &CallerCall, 8);
 			memcpy (&RelayPacket.dv.header.MyCall2, "ECHO", 4);
+        		crc = calc_crc (&RelayPacket.dv.header, 39);
+        		RelayPacket.dv.header.crc[0] = crc >> 8;
+        		RelayPacket.dv.header.crc[1] = crc & 0xff;
                         sendto (udpSocket, (char *)&RelayPacket, sizeof(RelayPacket), 0,
                                 (struct sockaddr *)&sndAddr, sizeof(sndAddr));
                 }
                 else
                 {
+                        send_pkt.B_header.PacketID[0] = (Packet_ID >> 8) & 0xff;
+                        send_pkt.B_header.PacketID[1] = Packet_ID & 0xff;
                         sndAddr.sin_addr = dstIP;
                         sndAddr.sin_port = dstPort;
                         sndAddr.sin_family = PF_INET;
                         memcpy (&send_pkt.header.MyCall, &client_call, 8);
                         memcpy (&send_pkt.header.YourCall, &CallerCall, 8);
                         memcpy (&send_pkt.header.MyCall2, "ECHO", 4);
+                        crc = calc_crc (&send_pkt.header, 39);
+                    	send_pkt.header.crc[0] = crc >> 8;
+                        send_pkt.header.crc[1] = crc & 0xff;
                         sendto (udpSocket, &send_pkt, 56, 0,
                                 (struct sockaddr *)&sndAddr, sizeof(sndAddr));
                 }
@@ -141,6 +153,8 @@ void	voice_frame_send(void)
 			memcpy	((char *)&RelayPacket.dv, (char *)&send_pkt, 27);
 			RelayPacket.ip = dstIP;
 			RelayPacket.port = dstPort;
+                        RelayPacket.dv.B_header.PacketID[0] = (Packet_ID >> 8) & 0xff;
+                        RelayPacket.dv.B_header.PacketID[1] = Packet_ID & 0xff;
 			sndAddr.sin_family = PF_INET;
 			sndAddr.sin_port = db_port;
 			sndAddr.sin_addr = dbIP;
@@ -149,6 +163,8 @@ void	voice_frame_send(void)
 		}
 		else
 		{
+                        send_pkt.B_header.PacketID[0] = (Packet_ID >> 8) & 0xff;
+                        send_pkt.B_header.PacketID[1] = Packet_ID & 0xff;
 			sndAddr.sin_addr = dstIP;
 			sndAddr.sin_port = dstPort;
 			sndAddr.sin_family = PF_INET;
@@ -185,8 +201,9 @@ void    ConSend(void)
         sndAddr.sin_family = PF_INET;
         sndAddr.sin_port = db_port;
         sndAddr.sin_addr = dbIP;
-	PacketIdSave[0] = send_pkt.B_header.PacketID[0];
-	PacketIdSave[1] = send_pkt.B_header.PacketID[1];
+	Packet_ID = rand();
+	PacketIdSave[0] = (Packet_ID >> 8) & 0xff;
+	PacketIdSave[1] = Packet_ID & 0xff;
 	send_msg.PacketID[0] = PacketIdSave[0];
 	send_msg.PacketID[1] = PacketIdSave[1];
 	memcpy (&send_msg.srcCall, &client_call, 8);
@@ -251,6 +268,7 @@ int main(int argc, const char **argv){
         signal(SIGINT,CloseSocket);
         signal(SIGTERM,CloseSocket);
 
+	srand ((unsigned) time (NULL));
 
 	config (argc, (char **)argv);
 
